@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,15 +26,12 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 
-void initInterfaces();
-void openAInterface(int fd, struct sockaddr * addr);
-void closeAllInterfaces();
-void freeAllInterfaces();
-void closeOldInterfaces();
-void closeInterfaceWithFD(int fd);
-void flushAllInterfaceBuffers();
-int interfacePrintWithFD(int fd, char * buffer, int len);
+void initInterfaces(void);
+void openAInterface(int fd, struct sockaddr *addr);
+void freeAllInterfaces(void);
+void closeOldInterfaces(void);
+int interfacePrintWithFD(int fd, char *buffer, int len);
 
-int doIOForInterfaces();
+int doIOForInterfaces(void);
 
 #endif
