@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu)
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,30 +18,31 @@
 
 #include "stats.h"
 
-#include "tables.h"
 #include "directory.h"
 #include "myfprintf.h"
 #include "player.h"
+#include "tag.h"
+#include "tagTracker.h"
 
 #include <time.h>
 
 Stats stats;
 
-void initStats() {
+void initStats(void)
+{
 	stats.daemonStart = time(NULL);
 	stats.numberOfSongs = 0;
-	/*stats.playTime = 0;
-	stats.songsPlayed = 0;*/
 }
 
-int printStats(FILE * fp) {
-	myfprintf(fp,"artists: %li\n",numberOfArtists());
-	myfprintf(fp,"albums: %li\n",numberOfAlbums());
-	myfprintf(fp,"songs: %i\n",stats.numberOfSongs);
-	myfprintf(fp,"uptime: %li\n",time(NULL)-stats.daemonStart);
-	myfprintf(fp,"playtime: %li\n",(long)(getPlayerTotalPlayTime()+0.5));
-	myfprintf(fp,"db_playtime: %li\n",stats.dbPlayTime);
-	/*myfprintf(fp,"songs_played: %li\n",stats.songsPlayed);*/
-	myfprintf(fp,"db_update: %li\n",getDbModTime());
+int printStats(int fd)
+{
+	fdprintf(fd, "artists: %i\n", getNumberOfTagItems(TAG_ITEM_ARTIST));
+	fdprintf(fd, "albums: %i\n", getNumberOfTagItems(TAG_ITEM_ALBUM));
+	fdprintf(fd, "songs: %i\n", stats.numberOfSongs);
+	fdprintf(fd, "uptime: %li\n", time(NULL) - stats.daemonStart);
+	fdprintf(fd, "playtime: %li\n",
+		  (long)(getPlayerTotalPlayTime() + 0.5));
+	fdprintf(fd, "db_playtime: %li\n", stats.dbPlayTime);
+	fdprintf(fd, "db_update: %li\n", getDbModTime());
 	return 0;
 }
