@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2004 by Warren Dukes (shank@mercury.chem.pitt.edu
+ * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,41 +21,66 @@
 
 #include "../config.h"
 
+#include "mpd_types.h"
+
+#include <string.h>
+
 #include <stdio.h>
 #ifdef HAVE_ID3TAG
-#ifdef USE_MPD_ID3TAG
-#include "libid3tag/id3tag.h"
-#else
 #include <id3tag.h>
 #endif
-#endif
+
+#define TAG_ITEM_ARTIST		0
+#define TAG_ITEM_ALBUM		1
+#define TAG_ITEM_TITLE		2
+#define TAG_ITEM_TRACK		3
+#define TAG_ITEM_NAME		4
+#define TAG_ITEM_GENRE		5
+#define TAG_ITEM_DATE		6
+#define TAG_ITEM_COMPOSER	7
+#define TAG_ITEM_PERFORMER	8
+#define TAG_ITEM_COMMENT	9
+#define TAG_ITEM_DISC      10
+
+#define TAG_NUM_OF_ITEM_TYPES	11
+
+extern char *mpdTagItemKeys[];
+
+typedef struct _MpdTagItem {
+	mpd_sint8 type;
+	char *value;
+} MpdTagItem;
 
 typedef struct _MpdTag {
-	char * artist;
-	char * album;
-	char * track;
-	char * title;
-	char * name;
 	int time;
+	MpdTagItem *items;
+	mpd_uint8 numOfItems;
 } MpdTag;
 
 #ifdef HAVE_ID3TAG
-MpdTag * parseId3Tag(struct id3_tag *);
+MpdTag *parseId3Tag(struct id3_tag *);
 #endif
 
-MpdTag * id3Dup(char * file);
+MpdTag *apeDup(char *file);
 
-MpdTag * newMpdTag();
+MpdTag *id3Dup(char *file);
 
-void clearMpdTag(MpdTag * tag);
+MpdTag *newMpdTag(void);
+
+void initTagConfig(void);
+
+void clearItemsFromMpdTag(MpdTag * tag, int itemType);
 
 void freeMpdTag(MpdTag * tag);
 
-void printMpdTag(FILE * fp, MpdTag * tag);
+void addItemToMpdTagWithLen(MpdTag * tag, int itemType, char *value, int len);
 
-MpdTag * mpdTagDup(MpdTag * tag);
+#define addItemToMpdTag(tag, itemType, value) \
+		addItemToMpdTagWithLen(tag, itemType, value, strlen(value))
 
-void validateUtf8Tag(MpdTag * tag);
+void printMpdTag(int fd, MpdTag * tag);
+
+MpdTag *mpdTagDup(MpdTag * tag);
 
 int mpdTagsAreEqual(MpdTag * tag1, MpdTag * tag2);
 
